#pragma once

#include <vector>
#include <ATLBase.h>

#pragma pack(push)
#pragma pack(1)

typedef struct DemiseItemName
{
   short iNameL;              // name size
   short iNameL2;             // name size again
   char  pName[0];               // name
}DemiseItemName;


typedef struct DemiseItem 
{
   short iIndex;              // item index number
   short iAttack;
   short iDefense;
   int iPrice;
   short iFLevel;             // find level
   short iFPercent;           // find percent     
   float fAbLevitate;         // abilities
   float fAbInvisible;
   float fAbSeeInvisible;
   float fAbProtect;
   float fAbCriticalHit;
   float fAbBackstab;
   float fAbBurn;
   float fAbFreeze;
   float fAbPoison;
   float fAbAcid;
   float fAbElectrocute;
   float fAbStone;
   float fAbBehead;
   float fAbModifyHits;
   float fAbModifySpells;
   float fAbSpellstrike;
   float fAbU1;
   
   short iSwings;
   short iSpecial;
   short iSpellSeq;
   short iSpellID;
   short iUses;
   char cU6[2];
   int iGuilds;               // Art = 1, Warr = 2, Pal = 4...    
   short iLevel;     
   float iPower;           
   int iAlign;                // u=1, g=2, n=4, e=8 (add together for diff combinations)
   short iHands;     
   short iClass;     
   short iRFire;              // resists
   short iRCold;
   short iRElec;
   short iRMind;
   short iRDisease;
   short iRPoison;
   short iRMagic;    
   short iRStone;
   short iRParalysis;
   short iRDrain;
   short iRAcid;
   
   char cU2[2];
   short iStr;                // stat requirements
   short iInt;
   short iWis;
   short iCon;
   short iCha;
   short iDex;
   char cU3[2];
   short iStrM;                // stat modifiers
   short iIntM;
   short iWisM;
   short iConM;
   short iChaM;
   short iDexM;
   char cU4[2];      
   
   short iCursed;             // 0 = not cursed, 1 = cursed, 2 = auto equip cursed
   short iSLevel;
   short iClassR;
   
   float iMHum;               // monster modifiers
   float iMSli;
   float iMDem;
   float iMDev;
   float iMEle;
   float iMRep;
   float iMDra;
   float iMAni;
   float iMIns;
   float iMUnd;
   float iMWat;
   float iMGia;
   float iMMyt;
   float iMLyc;
   float iMThi;
   float iMMag;
   float iMWar;
   float iMInd;
   float iMU1;
   float iMU2;
   float iMU3; 

   short iGuildItem;          // is it guild item?
   short iInfo;               // info text index
   short iSMod1;              // special modifiers
   short iSMod2;
   short iSMod3;
   short iSMod4;
   char cU1[38];              // only sound info left
} DemiseItem;

typedef struct DemiseItemsHeader
{
	char cHeader[12];             // header
	char cVersion[8];             // file version
	short iRev;                   // file revision
	short iItems;                 // number of items
} DemiseItemsHeader;

#pragma pack(pop)


class CDemiseItemList
{
private:
		CAutoVectorPtr<BYTE> m_pData;
		ULONGLONG m_ulSize;

public:
	std::vector<int> m_arrItemsIndex;
	std::vector<int> m_arrItemsNameIndex;
	CDemiseItemList(void);
	~CDemiseItemList(void);
	HRESULT LoadFile(const CString & strFileName);
	HRESULT SaveFile(const CString & strFileName);

	short GetTotalItems()  const { return static_cast<short>(m_arrItemsIndex.size()); }
	CString GetItemName(short iIndex)  const 
	{
		ATLASSERT(iIndex<GetTotalItems());
		DemiseItemName * pDemiseItemName = (DemiseItemName *)(m_pData.m_p + m_arrItemsNameIndex[iIndex]);
		CString strName(pDemiseItemName->pName,pDemiseItemName->iNameL);
		return strName;
	};


	DemiseItem * GetItem(short iIndex)  const 
	{
		ATLASSERT(iIndex<GetTotalItems());
		return (DemiseItem *)(m_pData.m_p + m_arrItemsIndex[iIndex]);

	};
};
